formattools.get_all_mark_format_contributions
=============================================

.. autofunction:: abjad.tools.formattools.get_all_mark_format_contributions.get_all_mark_format_contributions
   :noindex:
